<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://gleap.io
 * @since      1.0.0
 *
 * @package    Gleap
 * @subpackage Gleap/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Gleap
 * @subpackage Gleap/public
 * @author     Gleap <hello@gleap.io>
 */
class Gleap_Public
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gleap_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gleap_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{
		if (class_exists('FLBuilderModel') && FLBuilderModel::is_builder_active()) {
			return;
		}

		if (class_exists('\Elementor\Plugin') && \Elementor\Plugin::$instance->preview->is_preview()) {
			return;
		}

		$gleap_token = carbon_get_theme_option('gleap_token');
		if ($gleap_token) {
			$gleap_editors_only = carbon_get_theme_option('gleap_editors_only');
			if ($gleap_editors_only == true && !current_user_can('report_feedback')) {
				return;
			}

			$identify_script = "";
			$gleap_identity_token = carbon_get_theme_option('gleap_identity_token');
			if (is_user_logged_in() && $gleap_identity_token) {
				$user_data = get_userdata(get_current_user_id());
				$login = $user_data->user_login;
				$uname = $user_data->user_firstname . ' ' . $user_data->user_lastname;
				$nickname = (strlen($user_data->nickname) > 1) ? $user_data->nickname : '';
				$name = (strlen($uname) > 1) ? $uname : $nickname;
				$email = $user_data->user_email;
				$signature = hash_hmac('sha256', $login, $gleap_identity_token);
				$identify_script = ',Gleap.identify("' . $login . '", { name: "' . $name . '", email: "' . $email . '"}, "' . $signature . '");';
			}

			wp_register_script('gleap-sdk-js', '',);
			wp_enqueue_script('gleap-sdk-js');
			wp_add_inline_script('gleap-sdk-js', '!function(Gleap,t,i){if(!(Gleap=window.Gleap=window.Gleap||[]).invoked){for(window.GleapActions=[],Gleap.invoked=!0,Gleap.methods=["identify","clearIdentity","attachCustomData","setCustomData","removeCustomData","clearCustomData","registerCustomAction","logEvent","sendSilentCrashReport","startFeedbackFlow","setAppBuildNumber","setAppVersionCode","preFillForm","setApiUrl","setFrameUrl","isOpened","open","close","on","setLanguage","setOfflineMode","initialize"],Gleap.f=function(e){return function(){var t=Array.prototype.slice.call(arguments);window.GleapActions.push({e:e,a:t})}},t=0;t<Gleap.methods.length;t++)Gleap[i=Gleap.methods[t]]=Gleap.f(i);Gleap.load=function(){var t=document.getElementsByTagName("head")[0],i=document.createElement("script");i.type="text/javascript",i.async=!0,i.src="https://sdk.gleap.io/latest/index.js",t.appendChild(i)},Gleap.load(),Gleap.initialize("' . $gleap_token . '")' . $identify_script . '}}();');
		}
	}
}
